@@ -1,10 +1,10 @@
-# @(#)$Id: Authentication.pm 738 2009-06-09 16:42:23Z pjf $
+# @(#)$Id: Authentication.pm 757 2009-06-11 16:42:06Z pjf $
 
 package App::Munchies::Model::Authentication;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.2.%d', q$Rev: 738 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.3.%d', q$Rev: 757 $ =~ /\d+/gmx );
 use parent qw(CatalystX::Usul::Model::Schema);
 
 use Class::C3;
@@ -15,13 +15,13 @@ __PACKAGE__->config
      schema_class => q(App::Munchies::Schema::Authentication) );
 
 sub new {
-   my ($class, $app, @rest) = @_;
+   my ($self, $app, $config) = @_;
 
-   my $database = $rest[0]->{database} || $class->config->{database};
+   my $database = $config->{database} || $self->config->{database};
 
-   $class->config( connect_info => $class->connect_info( $app, $database ) );
+   $config->{connect_info} = $self->connect_info( $app, $database );
 
-   return $class->next::method( $app, @rest );
+   return $self->next::method( $app, $config );
 }
 
 1;
@@ -36,7 +36,7 @@ App::Munchies::Model::Authentication - Database authentication class
 
 =head1 Version
 
-0.1.$Revision: 738 $
+0.3.$Revision: 757 $
 
 =head1 Synopsis
 
